# pypiserver docs

Welcome to the documentation section of `pypiserver`.  

> :bulb: This documentation is still a work in progress
> and would benefit from your help.

## More information

If something is missing in the documentation here, maybe it is covered in
[README.md](../README.md).

## Documentation setup

> Some areas to describe are highlighted in
    [this issue](https://github.com/pypiserver/pypiserver/issues/368)
    ([#368](https://github.com/pypiserver/pypiserver/issues/368)),
    but feel free to add if you see something missing there.

The [`./contents`](./contents/) directory is designed to
 all the documentation files.

### How to contribute

Everyone is very welcome to extend `pypiserver` documentation.  

1. :thought_balloon: If you think of a topic you would like to describe, this is great.
2. :deciduous_tree: Fork this project and clone it locally to start your contribution.
3. :page_facing_up: Create a new Markdown (`<doc title>.md`) file/subdirectory+file inside the [`./contents`](./contents/):
   - :file_folder: Use subdirectories to organize related documentation into topics.
4. :octocat: Push your changes to your fork and open a PR to this repository.
5. :bell: Tag someone from the maintainers if you'd like, but in any case we will try to review the PR as soon as possible.
6. :dizzy: Once reviewed and accepted, your documentation will be merged into this repository.
